import math
def test_prime(n):
    if n <= 0:
        return('Number should be greater than zero')
    if n > 0 and n < 2:
        return(n,'is not prime number')
    if (n==2):
        return('2 is a prime number')
    x = math.floor(math.sqrt(n))
    for x in range(3,x+1,2):
        if(n % x==0):
            return (n,'is not a prime number because',(n//x),'times',x,'=',n)
    return (n,'is a prime number')



from setuptools import setup, find_packages

classifiers = [
  'Developement Status :: 5 - Production/Stable',
  'Intended Audience :: Education',
  'Operating System :: OS Independent',
  'License :: OSI Approved :: MIT License',
  'Programming Language :: Python :: 3'
]

setup(
  name='abhiprime',
  version='1.1.2',
  description='A program to check if the given number is a prime number or not',
  long_description=open('README.txt').read() + '\n\n' + open('CHANGELOG.txt').read(),
  url='',
  author='Abhishek Singh',
  author_email='abhisheksingh@ggits.org',
  License='MIT',
  classifier=classifiers,
  keywords='primenumber',
  packages=find_packages(),
  install_requires=['']
)
